## START: Set by rpmautospec
## (rpmautospec version 0.6.5)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 7;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%global srcname aiohttp

# We have attempted to run the tests with an older pytest than upstream wants,
# but pytest produces an INTERNALERROR
%bcond_with tests

Name:           python-%{srcname}
Version:        3.7.4
Release:        %autorelease
Summary:        Python HTTP client/server for asyncio

License:        Apache-2.0
URL:            https://github.com/aio-libs/aiohttp
Source0:        %{url}/archive/v%{version}/%{srcname}-%{version}.tar.gz
# Unbundle http-parser
Patch0:         unbundle-http-parser.patch

# Allow chardet 4+, merged upstream
# https://github.com/aio-libs/aiohttp/commit/b0ed732d0a
Patch1:         chardet4.patch
# Cherry-pick commit 9118a5831e8a65b8c839eb7e4ac983e040ff41df to v3.7.4.
# This corresponds to:
#   [PR #8079/1c335944 backport][3.9] Validate static paths
#   https://github.com/aio-libs/aiohttp/pull/8080
# and to:
#   Validate static paths
#   https://github.com/aio-libs/aiohttp/pull/8079
# This fixes:
#   CVE-2024-23334 python-aiohttp: aiohttp: follow_symlinks directory traversal
#   vulnerability [epel-all]
#   https://bugzilla.redhat.com/show_bug.cgi?id=2261892
#
#   aiohttp.web.static(follow_symlinks=True) is vulnerable to directory
#   traversal
#   https://github.com/aio-libs/aiohttp/security/advisories/GHSA-5h86-8mv2-jq9f
Patch2:         0001-PR-8079-1c335944-backport-3.9-Validate-static-paths-.patch
# Security fix for CVE-2024-52304
# See “Request smuggling due to incorrect parsing of chunk extensions”
# https://github.com/aio-libs/aiohttp/security/advisories/GHSA-8495-4g3g-x7pr
# https://github.com/aio-libs/aiohttp/commit/259edc369075de63e6f3a4eaade058c62af0df71
# Rebased on v3.9.5.
Patch3:         0001-Fix-incorrect-parsing-of-chunk-extensions-with-the-p.patch

BuildRequires:  gcc
BuildRequires:  http-parser-devel

# EPEL8 is utilizing the CentOS Devel repo for some packages.  However, this is
# not available for s390x, so exclude it.
# https://fedoraproject.org/wiki/EPEL/FAQ#RHEL_8.2B_has_binaries_in_the_release.2C_but_is_missing_some_corresponding_-devel_package._How_do_I_build_a_package_that_needs_that_missing_-devel_package.3F
%if %{defined el8}
ExcludeArch:    s390x
%endif

%description
Python HTTP client/server for asyncio which supports both the client and the
server side of the HTTP protocol, client and server websocket, and webservers
with middlewares and pluggable routing.

%package -n python3-%{srcname}
Summary:        %{summary}

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-Cython
BuildRequires:  python3-multidict

%if %{with tests}
# Test machinery
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-mock
# Test dependencies (some of which are runtime dependencies)
BuildRequires:  python3-async-generator
BuildRequires:  python3-async-timeout
BuildRequires:  python3-attrs
BuildRequires:  python3-brotli
BuildRequires:  python3-chardet
BuildRequires:  python3-freezegun
BuildRequires:  python3-gunicorn
BuildRequires:  python-idna-ssl
# Not currently packaged:
# BuildRequires:  python3dist(proxy-py)
BuildRequires:  python3-re-assert
BuildRequires:  python3-trustme
BuildRequires:  python3-typing-extensions
BuildRequires:  python3-yarl
%endif

Recommends:     python%{python3_version}dist(aiodns)
%{?python_provide:%python_provide python3-%{srcname}}

%description -n python3-%{srcname}
Python HTTP client/server for asyncio which supports both the client and the
server side of the HTTP protocol, client and server websocket, and webservers
with middlewares and pluggable routing.

%prep
%autosetup -p 1 -n %{srcname}-%{version}
# Make sure the source archive does not include any files generated by Cython
grep -rl '/\* Generated by Cython' | xargs -r rm -v
# Disable test coverage reports
sed -r -i '/--cov=/d' setup.cfg
# requires pytest-3.8.2, actual pytest-3.4.2; let’s do what we can anyway
sed -r -i 's/(minversion[[:blank:]]*=[[:blank:]]*)3\.8\.2/\13\.4\.2/' setup.cfg

%build
# Recreate removed Cython files using commands extracted from the Makefile.
# We don't run make directly, as it pip-installs Cython.
#
# We don't need a real git checkout, but we do need a .git directory to help
# certain scripts find the root of the source tree.
mkdir -p .git
# See the aiohttp/_find_header.c target in the Makefile; this also generates
# _headers.pyi.
%{python3} tools/gen.py
# Now we can invoke Cython.
%{python3} -m cython -3 aiohttp/*.pyx -I aiohttp
# Now we need to remove the .git directory again, because its presence will
# lead the actual build astray, something like:
#   Install submodules when building from git clone
#   Hint:
#     git submodule update --init
rm -rvf .git
%py3_build

%install
%py3_install

%if %{with tests}
%check
# test_proxy_functional.py requires python3dist(proxy-py)
ignore="${ignore-} --ignore=tests/test_proxy_functional.py"
# Requires network access (at least DNS)
k="${k-}${k+ and }not test_client_session_timeout_zero"
k="${k-}${k+ and }not test_mark_formdata_as_processed"
# E           Exception: Asynchronous fixtures must depend on the 'loop'
#             fixture or be used in tests depending from it.
# (not investigated; perhaps because pytest is too old?)
k="${k-}${k+ and }not test_foo_without_loop"
# E       fixture 'tmp_path' not found
# (apparently because pytest is too old)
k="${k-}${k+ and }not test_follow_symlink_directory_traversal[pyloop]"
k="${k-}${k+ and }not test_static_head[pyloop]"
# E           AttributeError: 'brotli.Decompressor' object has no attribute
#             'decompress'
# (apparently because python3-brotli is too old or too new)
k="${k-}${k+ and }not (TestParsePayload and test_http_payload_brotli)"
# E       TypeError: assert_outcomes() got an unexpected keyword argument
#         'errors'
# (not investigated)
k="${k-}${k+ and }not test_aiohttp_plugin_async_fixture"
%pytest ${ignore-} -k "${k-}" -rs -v
%endif

%files -n python3-%{srcname}
%doc CHANGES.rst CONTRIBUTING.rst CONTRIBUTORS.txt HISTORY.rst README.rst
%license LICENSE.txt
%{python3_sitearch}/%{srcname}-*.egg-info/
%{python3_sitearch}/%{srcname}/

%changelog
## START: Generated by rpmautospec
* Tue Nov 19 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 3.7.4-7
- Security fix for CVE-2024-52304 (fixes RHBZ#2327151)

* Tue Nov 19 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 3.7.4-6
- Update License to SPDX

* Tue Nov 19 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 3.7.4-5
- Attempt and fail to Run the tests

* Tue Nov 19 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 3.7.4-4
- Actually build the compiled extensions
- Stop disabling debug packages

* Tue Jan 30 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 3.7.4-2
- Backport patch for CVE-2024-23334 (fix RHBZ#2261892)

* Sat Feb 27 2021 Fabian Affolter <mail@fabian-affolter.ch> - 3.7.4-1
- Update to latest upstream release 3.7.4

* Thu Feb 04 2021 Miro Hrončok <mhroncok@redhat.com> - 3.7.3-3
- Allow installation with chardet 4

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 3.7.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Fri Dec 11 2020 Fabian Affolter <mail@fabian-affolter.ch> - 3.7.3-1
- Update to latest upstream release 3.7.3

* Wed Dec 09 2020 Fabian Affolter <mail@fabian-affolter.ch> - 3.7.2-1
- Update to latest upstream release 3.7.2

* Mon Oct 26 2020 Fabian Affolter <mail@fabian-affolter.ch> - 3.7.1-1
- Update to new upstream version 3.7.1

* Wed Oct 14 2020 Fabian Affolter <mail@fabian-affolter.ch> - 3.6.3-1
- Update to new upstream version 3.6.3

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 3.6.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sun May 24 2020 Miro Hrončok <mhroncok@redhat.com> - 3.6.2-4
- Rebuilt for Python 3.9

* Wed Apr 08 2020 Carl George <carl@george.computer> - 3.6.2-3
- Don't build for s390x on EL8

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 3.6.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Fri Oct 25 2019 Fabian Affolter <mail@fabian-affolter.ch> - 3.6.2-1
- Update to new upstream version 3.6.2

* Sat Sep 21 2019 Fabian Affolter <mail@fabian-affolter.ch> - 3.6.1-1
- Update to new upstream version 3.6.1

* Wed Sep 18 2019 Fabian Affolter <mail@fabian-affolter.ch> - 3.6.0-1
- Update to new upstream version 3.6.0

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 3.5.4-5
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 3.5.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sat Jun 01 2019 Fabian Affolter <mail@fabian-affolter.ch> - 3.5.4-3
- Remove dep generator

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 3.5.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jan 12 2019 Fabian Affolter <mail@fabian-affolter.ch> - 3.5.4-1
- Update to new upstream version 3.5.4

* Fri Jan 11 2019 Fabian Affolter <mail@fabian-affolter.ch> - 3.5.3-1
- Update to new upstream version 3.5.3

* Thu Jan 10 2019 Fabian Affolter <mail@fabian-affolter.ch> - 3.5.2-1
- Update to new upstream version 3.5.2

* Wed Dec 26 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.5.1-1
- Update to new upstream version 3.5.1

* Thu Sep 06 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.4.4-1
- Update to new upstream version 3.4.4 (rhbz#1625634)

* Wed Sep 05 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 3.4.3-1
- Update to 3.4.3

* Sun Sep 02 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 3.4.2-1
- Update to 3.4.2

* Mon Aug 27 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 3.4.0-4
- Unbundle http-parser (rhbz#1622508)

* Mon Aug 27 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.4.0-3
- Fix rhbz#1622310

* Sat Aug 25 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 3.4.0-2
- Recommend aiodns

* Sat Aug 25 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.4.0-1
- Update to new upstream version 3.4.0 (rhbz#1622288)

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.3.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 3.3.2-2
- Rebuilt for Python 3.7

* Tue Jun 12 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.3.2-1
- Update to new upstream version 3.3.2

* Wed Jun 06 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.3.1-1
- Update to new upstream version 3.3.1

* Fri Jun 01 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.3.0-1
- Update to new upstream version 3.3.0 (rhbz#1585170)

* Thu May 10 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.2.1-1
- Update to new upstream version 3.2.1 (rhbz#1576796)

* Mon May 07 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.2.0-1
- Update to new upstream version 3.2.0 (rhbz#1575435)

* Sat Apr 14 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.1.3-1
- Update to new upstream version 3.1.3 (rhbz#1567093)

* Fri Apr 06 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.1.2-1
- Update to new upstream version 3.1.2

* Tue Mar 27 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.1.1-1
- Update to new upstream version 3.1.1

* Fri Mar 23 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.1.0-1
- Update to new upstream version 3.1.0

* Thu Mar 15 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.0.9-1
- Update to new upstream version 3.0.9 (rhbz#1556612)

* Tue Mar 13 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.0.8-1
- Update to new upstream version 3.0.8

* Fri Mar 09 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.0.7-1
- Update to new upstream version 3.0.7 (rhbz#1548601)

* Tue Mar 06 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.0.6-1
- Update to new upstream version 3.0.6 (rhbz#1548601)

* Wed Feb 28 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.0.5-1
- Update to new upstream version 3.0.5 (rhbz#1548601)

* Mon Feb 12 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.0.1-1
- Update to new upstream version 3.0.1

* Mon Feb 12 2018 Fabian Affolter <mail@fabian-affolter.ch> - 3.0.0-1
- Update to new upstream version 3.0.0 (rhbz#1544413)

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.10-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Feb 02 2018 Fabian Affolter <mail@fabian-affolter.ch> - 2.3.10-1
- Update to new upstream version 2.3.10 (rhbz#1541369)

* Fri Jan 19 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 2.3.9-2
- Enable usage of dependency generator

* Wed Jan 17 2018 Igor Gnatenko <ignatenko@redhat.com> - 2.3.9-1
- Update to 2.3.9

* Mon Jan 15 2018 Fabian Affolter <mail@fabian-affolter.ch> - 2.3.8-1
- Update to new upstream version 2.3.8

* Wed Dec 27 2017 Fabian Affolter <mail@fabian-affolter.ch> - 2.3.7-1
- Update to new upstream version 2.3.7 (rhbz#1529275)

* Mon Dec 04 2017 Fabian Affolter <mail@fabian-affolter.ch> - 2.3.6-1
- Update to new upstream version 2.3.6

* Fri Dec 01 2017 Fabian Affolter <mail@fabian-affolter.ch> - 2.3.5-1
- Update to new upstream version 2.3.5

* Fri Nov 17 2017 Fabian Affolter <mail@fabian-affolter.ch> - 2.3.3-1
- Update to new upstream version 2.3.3 (rhbz#1514434)

* Thu Nov 02 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 2.3.2-1
- Update to 2.3.2

* Fri Oct 20 2017 Fabian Affolter <mail@fabian-affolter.ch> - 2.3.1-1
- Update to new upstream version 2.3.1 (rhbz#1504339)

* Wed Oct 18 2017 Fabian Affolter <mail@fabian-affolter.ch> - 2.3.0-1
- Update to new upstream version 2.3.0

* Fri Aug 04 2017 Fabian Affolter <mail@fabian-affolter.ch> - 2.2.5-1
- Update to new upstream version 2.2.5

* Thu Aug 03 2017 Fabian Affolter <mail@fabian-affolter.ch> - 2.2.4-1
- Update to new upstream version 2.2.4

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.2.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.2.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Thu Jul 06 2017 Fabian Affolter <mail@fabian-affolter.ch> - 2.2.3-1
- Update to new upstream version 2.2.3 (rhbz#1467742)

* Mon Jul 03 2017 Fabian Affolter <mail@fabian-affolter.ch> - 2.2.2-1
- Update to new upstream version 2.2.2

* Mon Jul 03 2017 Fabian Affolter <mail@fabian-affolter.ch> - 2.2.1-1
- Update to new upstream version 2.2.1 (rhbz#1467114)

* Tue Jun 20 2017 Fabian Affolter <mail@fabian-affolter.ch> - 2.2.0-1
- Update to new upstream version 2.2.0 (rhbz#1463234)

* Sat May 27 2017 Fabian Affolter <mail@fabian-affolter.ch> - 2.1.0-1
- Update URL
- Update to new upstream version 2.1.0 (rhbz#1456063)

* Fri Apr 14 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 2.0.7-1
- Update to 2.0.7

* Fri Apr 07 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 2.0.6-1
- Update to 2.0.6

* Thu Mar 30 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 2.0.5-1
- Update to 2.0.5

* Tue Mar 28 2017 Igor Gnatenko <ignatenko@redhat.com> - 2.0.4-1
- Update to 2.0.4

* Sat Mar 25 2017 Fabian Affolter <mail@fabian-affolter.ch> - 2.0.3-1
- Update to new upstream version 2.0.3 (rhbz#1435844)

* Thu Mar 23 2017 Igor Gnatenko <ignatenko@redhat.com> - 2.0.2-3
- Specify proper yarl version

* Thu Mar 23 2017 Igor Gnatenko <ignatenko@redhat.com> - 2.0.2-2
- Fix requires

* Thu Mar 23 2017 Fabian Affolter <mail@fabian-affolter.ch> - 2.0.2-1
- Update to new upstream version 2.0.2 (rhbz#1432690)

* Wed Mar 15 2017 Igor Gnatenko <ignatenko@redhat.com> - 1.3.4-1
- Update to 1.3.4

* Mon Feb 20 2017 Fabian Affolter <mail@fabian-affolter.ch> - 1.3.3-1
- Update to new upstream version 1.3.3 (rhbz#1423053)

* Thu Feb 09 2017 Igor Gnatenko <ignatenko@redhat.com> - 1.3-1
- Update to 1.3

* Sun Jan 22 2017 Fabian Affolter <mail@fabian-affolter.ch> - 1.2-1
- Update to new upstream version 1.2
- Add new requirement
- Add real description

* Sun Jan 01 2017 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 1.0.5-3
- Add missing dependency on async-timeout (RHBZ #1391287)

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 1.0.5-2
- Rebuild for Python 3.6

* Mon Oct 31 2016 Fabian Affolter <mail@fabian-affolter.ch> - 1.0.5-1
- Update to new upstream version 1.0.5

* Tue Aug 30 2016 Fabian Affolter <mail@fabian-affolter.ch> - 0.22.5-1
- Update to new upstream version 0.22.5

* Wed Aug 10 2016 Igor Gnatenko <ignatenko@redhat.com> - 0.21.6-4
- Move requires under real subpackage

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.21.6-3
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Jun 23 2016 Igor Gnatenko <ignatenko@redhat.com> - 0.21.6-2
- Add missing Requires: python3-multidict (RHBZ #1349576)

* Thu May 12 2016 Igor Gnatenko <ignatenko@redhat.com> - 0.21.6-1
- Update to 0.21.6

* Tue Mar 22 2016 Fabian Affolter <mail@fabian-affolter.ch> - 0.21.5-1
- Update to new upstream version 0.21.5

* Sat Mar 05 2016 Fabian Affolter <mail@fabian-affolter.ch> - 0.21.2-1
- Update to new upstream version 0.21.2

* Sun Feb 14 2016 Fabian Affolter <mail@fabian-affolter.ch> - 0.21.1-1
- Add requirements (rhbz#1300186)
- Update to new upstream version 0.21.1

* Thu Feb 04 2016 Fabian Affolter <mail@fabian-affolter.ch> - 0.21.0-1
- Update to new upstream version 0.21.0

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.19.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Nov 27 2015 Fabian Affolter <mail@fabian-affolter.ch> - 0.19.0-1
- Update py3
- Update to new upstream version 0.19.0

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.17.4-2
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Fri Oct 16 2015 Fabian Affolter <mail@fabian-affolter.ch> - 0.17.4-1
- Update to new upstream version 0.17.4

* Sat Aug 01 2015 Fabian Affolter <mail@fabian-affolter.ch> - 0.16.6-2
- Fix license

* Sat Aug 01 2015 Fabian Affolter <mail@fabian-affolter.ch> - 0.16.6-1
- Update to lastest upstream release 0.16.6 (rhbz#1231670)

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.16.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Jun 15 2015 Fabian Affolter <mail@fabian-affolter.ch> - 0.16.5-1
- Update to lastest upstream release 0.16.5 (rhbz#1231670)

* Wed Nov 26 2014 Fabian Affolter <mail@fabian-affolter.ch> - 0.10.2-1
- Update to lastest upstream release 0.10.2

* Wed Oct 08 2014 Fabian Affolter <mail@fabian-affolter.ch> - 0.9.1-2
- Build only a py3 package

* Wed Feb 26 2014 Fabian Affolter <mail@fabian-affolter.ch> - 0.9.1-1
- Initial package for Fedora

## END: Generated by rpmautospec
